@@ -47,11 +47,7 @@ class MQManager(Singleton):
         if not hasattr(self, 'mq'):
             self.mq = await open_connection(self.host, self.port)
         
-        if not self.mq.status == ConnectionStatus.CONNECTED:
-            await self.close_async()
-            return await self.get_mq_conn()
-        else:
-            return self.mq
+        return self.mq
             
     def _encode_message(self, message):
         if isinstance(message, str):
